﻿using System;
using System.Drawing;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;

namespace WpfApplication1.ViewModels
{
    public class Pane1ViewModel : ViewModelBase
    {
        #region fields

        private String[] _colorTexts = { "White", "Red", "Yellow", "Green", "Black" };

        private Int32 _counter = 0;

        #endregion fields

        #region properties

        public static Pane1ViewModel Instance
        {
            get;
            private set;
        }

        public string MainButtonContent
        {
            get;
            private set;
        }

        private String _foregroundColor;

        public String ForegroundColor
        {
            get
            {
                return _foregroundColor;
            }
            private set
            {
                if ( !String.IsNullOrWhiteSpace(value) && !_foregroundColor.Equals(value) )
                {
                    _foregroundColor = value;

                    RaisePropertyChanged(nameof(ForegroundColor));
                }
            }
        }

        private String _backgroundColor;

        public String BackgroundColor
        {
            get
            {
                return _backgroundColor;
            }
            private set
            {
                if ( !String.IsNullOrWhiteSpace(value) && !_backgroundColor.Equals(value) )
                {
                    _backgroundColor = value;

                    RaisePropertyChanged(nameof(BackgroundColor));
                }
            }
        }

        public Int32 Counter
        {
            get
            {
                return _counter;
            }
            private set
            {
                if ( _counter != value )
                {
                    _counter = value;
                    RaisePropertyChanged(nameof(Counter));
                }
            }
        }

        #endregion properties

        #region commands

        private RelayCommand _switchBackgroundColorCommand;

        public RelayCommand SwitchBackgroundColorCommand
        {
            get
            {
                return _switchBackgroundColorCommand ?? (_switchBackgroundColorCommand = new RelayCommand(() =>
                {
                    BackgroundColor = (_colorTexts[_counter]);
                    ForegroundColor = (BackgroundColor.Equals("Black") ? "White" : "Black");
                    Counter = (_counter + 1) % _colorTexts.Length;
                }));
            }
            set
            {
                _switchBackgroundColorCommand = value;
            }
        }

        #endregion commands

        #region constructors

        static Pane1ViewModel()
        {
            Instance = new Pane1ViewModel();
        }

        private Pane1ViewModel()
        {
            MainButtonContent = "Switch Color";
            _backgroundColor = "White";
            _foregroundColor = "Black";
        }

        #endregion constructors
    }
}